@@ -21,9 +21,17 @@ ac_get_campaigns_messages <- function(
 
   # send requests
   list_data <- pblapply(campaign_ids, function(cid) {
-    ans <- GET(str_glue("{Sys.getenv('ACTIVECAMPAGN_API_URL')}/api/3/campaigns/{cid}/campaignMessages"),
-               query = list(limit = -1),
-               add_headers("Api-Token" = Sys.getenv('ACTIVECAMPAGN_API_TOKEN')))
+
+    retry(
+      {
+        ans <- GET(str_glue("{Sys.getenv('ACTIVECAMPAGN_API_URL')}/api/3/campaigns/{cid}/campaignMessages"),
+                   query = list(limit = -1),
+                   add_headers("Api-Token" = Sys.getenv('ACTIVECAMPAGN_API_TOKEN')))
+      },
+      until =  ~ status_code(.) == 200,
+      interval  = getOption('ractivecampaig.max_tries'),
+      max_tries = getOption('ractivecampaig.interval')
+    )
 
     data <- content(ans)
 
