@@ -41,7 +41,7 @@ ac_get_custom_contact_fields <- function() {
 
     is_first_iteration <- FALSE
     offset <- offset + limit
-    total  <- data$meta$total
+    total  <- as.numeric(data$meta$total)
     res <- append(res, list(out_data))
 
     Sys.sleep(0.25)
