@@ -31,12 +31,19 @@ ac_get_custom_contact_fields_values <- function(
   while ( (is.na(total) | offset <= total) | is_first_iteration  ) {
 
     # send request
-    ans <- GET(str_glue("{Sys.getenv('ACTIVECAMPAGN_API_URL')}/api/3/fieldValues"),
-               query = list(limit  = limit,
-                            offset = offset,
-                            "filters[fieldid]" = field_id,
-                            "filters[val]" = val),
-               add_headers("Api-Token" = Sys.getenv('ACTIVECAMPAGN_API_TOKEN')))
+    retry(
+      {
+        ans <- GET(str_glue("{Sys.getenv('ACTIVECAMPAGN_API_URL')}/api/3/fieldValues"),
+                   query = list(limit  = limit,
+                                offset = offset,
+                                "filters[fieldid]" = field_id,
+                                "filters[val]" = val),
+                   add_headers("Api-Token" = Sys.getenv('ACTIVECAMPAGN_API_TOKEN')))
+          },
+        until = ~ status_code(.) == 200,
+        interval  = getOption('ractivecampaig.max_tries'),
+        max_tries = getOption('ractivecampaig.interval')
+    )
 
     data <- content(ans)
 
@@ -49,7 +56,7 @@ ac_get_custom_contact_fields_values <- function(
 
     is_first_iteration <- FALSE
     offset <- offset + limit
-    total  <- data$meta$total
+    total  <- as.numeric(data$meta$total)
     res <- append(res, list(out_data))
 
     Sys.sleep(0.25)
